@@ -111,7 +111,7 @@ class DirectusApi:
                 params={'limit': page_size, 'meta': '*', 'page': page})
 
         # Set page_size to limit if limit is smaller than page_size
-        if limit < page_size:
+        if limit is not None and limit < page_size:
             page_size = limit
 
         response = __helper(page_size=page_size, page=1, filter_dict=filter_dict)
